% This function estimates the population size based on the M_th model
% discussed in [1]. The formula is given in Equation (3.18).
%
% Input:
% contMat is an SxM matrix where element ij is equal to the number of times
% that agent j contacts (or detects) individual i, for 1 <= i <= S and 1 <= j <= M.
%
% Output:
% Nhat is the estimated population size
%
% [1]: Estimating population size via sample coverage for closed capture-recapture
% models, S. Lee and A. Chao, Biometrics, 1994

function Nhat = chao1(contMat)
M = size(contMat, 2);
n_agent = sum(contMat ~= 0, 1);
f1 = sum(contMat ~= 0, 2);
D = size(contMat, 1);
F = zeros(M, 1);
for i = 1:M
    F(i) = sum(f1 == i);
end

temp = 0;
for k = 2:M
    for j = 1:k - 1
        temp = temp + n_agent(k) * n_agent(j);
    end
end
temp = 2 * temp;

Chat1 = 1 - F(1) / sum([1:M]'.*F);
Nhat0 = D / Chat1;
gamma = Nhat0 * sum([1:M] .* [0:M - 1] .* F')/temp-1;

Nhat = Nhat0 + F(1) / Chat1 * max(gamma, 0);
Nhat = ceil(Nhat);