% This function estimates the population size based on the model discussed in
% [1]. The formula is given in Section V of [1].
%
% Input:
% sumConts is an S-element vector where element i is equal to the total number of times
% that individual i is contacted (or detected) by all agents, for 1 <= i <=
% S, where S is the number of discovered individuals.
%
% Output:
% Nhat is the estimated population size
%
% [1]: Population estimation with performance guarantees, A. Orlitsky, N. Santhanam
% and K. Viswanathan, IEEE International Symposium on Information Theory (ISIT), 2007

function Nhat = orlitsky1(sumConts)

Nr = sum(sumConts);
r = Nr - length(sumConts);
Nhat = ceil(exp(logStirling2(Nr, Nr - r) - logStirling2(Nr - 1, Nr - r)));

% This function computes the logarithm of the Stirling numbers of the second kind
function logB = logStirling2(n, k)

j = [0:k];
w = (- 1) .^ (k - j);
x = gammaln(k + 1) - gammaln(j + 1) - gammaln(k - j + 1) + n * log(j);
y = maxstar(x, w);
logB = y - gammaln(k + 1);